#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-FTusCtIzD0VCTokXCBu5v7
key:                  basic-prelude-0.7.0-FTusCtIzD0VCTokXCBu5v7
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  fd95f29287d7283c637f7b71f435cfac
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-8.10.5/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/basic-prelude-0.7.0
hs-libraries:         HSbasic-prelude-0.7.0-FTusCtIzD0VCTokXCBu5v7
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    filepath-1.4.2.1 hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE
    text-1.2.4.1 transformers-0.5.6.2
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

